/*
 * Simple MapBox viewer to demonstrate communication between
 * a RepeaterFlex item plugin and associated script.
 */

var Maps = { };	// Array to hold information about map instances (may be multiple per page)

function setMapLayer(mapID, styleId)	// Utility function to update visible layer (may switch style during runtime)
	{
	if(Maps[mapID].styleLayer)
		Maps[mapID].map.removeLayer(Maps[mapID].styleLayer);

	Maps[mapID].styleLayer = L.mapbox.styleLayer('mapbox://styles/'+styleId);
	Maps[mapID].map.addLayer(Maps[mapID].styleLayer);
	}

function setStyle(s)	// onClick function to set a map style (see getStyleSelect in PHP code)
	{
//	console.log(s.parentNode.dataset.style);
	setMapLayer(s.parentNode.dataset.mapid, s.parentNode.dataset.style);
	}

$(document).ready(function() {
	$('.FlexMapBox').each(function(){		// Initialize any FlexMapBox instance
		var $box = jQuery(this);			// reference to the div
		var $mapID = $box.attr('id');		// We need this id for proper association with the container
		var mapCfg = config.MapBox[$mapID];	// Shortkey to our instance variables
//		console.log(mapCfg);
	
		L.mapbox.accessToken = config.MapBox.accesskey;			// Initialize access token with Leaflet MapBox
		Maps[$mapID] = { };										// Create container object
		Maps[$mapID].map = L.mapbox.map($mapID, undefined, {	// Initialize map
			maxZoom: 18
			});
		Maps[$mapID].map.setView(mapCfg.origin, mapCfg.zoom);	// Initialize view
		setMapLayer($mapID, mapCfg.style);		// Configure layer
	
		if('mapmarker' in mapCfg)	// Do we have a mapmarker image defined?
			{
//			console.log(mapCfg.mapmarker);
			// Generate a Leaflet Icon to be placed in our marker layer
			var mapMarker = L.icon({
				iconUrl: mapCfg.mapmarker.url,	// We may want to sanitize these parameters
				iconSize: mapCfg.mapmarker.iconsize,
				iconAnchor: mapCfg.mapmarker.iconanchor,
				popupAnchor: mapCfg.mapmarker.popupanchor,
//    shadowUrl: 'my-icon-shadow.png',		// Well, not implemented here...
//    shadowSize: [68, 95],
//    shadowAnchor: [22, 94]
				});
				
			// Create a new layer for our marker and add it to the map
			layerMarker = new L.featureGroup();
			Maps[$mapID].map.addLayer(layerMarker);

			// Iterate through all provided marker entries and place a marker
			for(var m of mapCfg.marker)
				{
				var marker = L.marker(m.origin, {icon: mapMarker}).addTo(layerMarker);
				marker.markerid = m.id;
				marker.bindPopup(m.title);
				}
			}
	
		});
	});
